==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressPodTemplateBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ACMEChallengeSolverHTTP01IngressPodTemplateBuilder extends ACMEChallengeSolverHTTP01IngressPodTemplateFluent<ACMEChallengeSolverHTTP01IngressPodTemplateBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressPodTemplate,ACMEChallengeSolverHTTP01IngressPodTemplateBuilder>{
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder() {
    this(false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(Boolean validationEnabled) {
    this(new ACMEChallengeSolverHTTP01IngressPodTemplate(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent) {
    this(fluent, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressPodTemplate(), validationEnabled);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this(fluent, instance, false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodTemplate instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressPodTemplate());

    if (instance != null) {
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this(instance,false);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplate instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressPodTemplate());

    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
    }
    this.validationEnabled = validationEnabled; 
  }
  ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent;
  Boolean validationEnabled;
  public ACMEChallengeSolverHTTP01IngressPodTemplate build() {
    ACMEChallengeSolverHTTP01IngressPodTemplate buildable = new ACMEChallengeSolverHTTP01IngressPodTemplate(fluent.buildMetadata(),fluent.buildSpec());
    return buildable;
  }
  
}

==> certmanager-model-v1alpha3-6.10.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEChallengeSolverHTTP01IngressPodTemplateBuilder.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
public class ACMEChallengeSolverHTTP01IngressPodTemplateBuilder extends ACMEChallengeSolverHTTP01IngressPodTemplateFluent<ACMEChallengeSolverHTTP01IngressPodTemplateBuilder> implements VisitableBuilder<ACMEChallengeSolverHTTP01IngressPodTemplate,ACMEChallengeSolverHTTP01IngressPodTemplateBuilder>{
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder() {
    this(new ACMEChallengeSolverHTTP01IngressPodTemplate());
  }
  
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent) {
    this(fluent, new ACMEChallengeSolverHTTP01IngressPodTemplate());
  }
  
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent,ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this.fluent = fluent;
    fluent.copyInstance(instance);
  }
  
  public ACMEChallengeSolverHTTP01IngressPodTemplateBuilder(ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this.fluent = this;
    this.copyInstance(instance);
  }
  ACMEChallengeSolverHTTP01IngressPodTemplateFluent<?> fluent;
  
  public ACMEChallengeSolverHTTP01IngressPodTemplate build() {
    ACMEChallengeSolverHTTP01IngressPodTemplate buildable = new ACMEChallengeSolverHTTP01IngressPodTemplate(fluent.buildMetadata(),fluent.buildSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  

}
